summaryrefslogtreecommitdiff
path: root/homedecor/doors_and_gates.lua
diff options
context:
space:
mode:
authorVanessa Ezekowitz <vanessaezekowitz@gmail.com>2017-02-26 11:11:19 -0500
committerVanessa Ezekowitz <vanessaezekowitz@gmail.com>2017-02-26 11:11:19 -0500
commit2b5664c0004b2f4ed8c712b8b6f75d9d3294c829 (patch)
tree2d1f641ae5a98fafcc8564670bd9e0077da900d2 /homedecor/doors_and_gates.lua
parent7315a13c3a5369688fffef20ab6a5877f506a459 (diff)
downloaddreambuilder_modpack-2b5664c0004b2f4ed8c712b8b6f75d9d3294c829.tar
dreambuilder_modpack-2b5664c0004b2f4ed8c712b8b6f75d9d3294c829.tar.gz
dreambuilder_modpack-2b5664c0004b2f4ed8c712b8b6f75d9d3294c829.tar.bz2
dreambuilder_modpack-2b5664c0004b2f4ed8c712b8b6f75d9d3294c829.tar.xz
dreambuilder_modpack-2b5664c0004b2f4ed8c712b8b6f75d9d3294c829.zip
updated lots of mods:
blox, bobblocks, homedecor, coloredwood, gloopblocks, moreblocks, plasticbox, replacer, solidcolor, stained_glass, technic, unifiedbricks, and unifieddyes (in most of these, it's to upgrade to the Unified Dyes "extended" palette)
Diffstat (limited to 'homedecor/doors_and_gates.lua')
-rw-r--r--homedecor/doors_and_gates.lua27
1 files changed, 19 insertions, 8 deletions
diff --git a/homedecor/doors_and_gates.lua b/homedecor/doors_and_gates.lua
index 81d8583..f29ea24 100644
--- a/homedecor/doors_and_gates.lua
+++ b/homedecor/doors_and_gates.lua
@@ -293,10 +293,12 @@ end
-- Gates
local gate_list = {
- { "picket", S("Unpainted Picket Fence Gate") },
- { "picket_white", S("White Picket Fence Gate") },
- { "barbed_wire", S("Barbed Wire Fence Gate") },
- { "chainlink", S("Chainlink Fence Gate") },
+ { "picket", S("Unpainted Picket Fence Gate") },
+ { "picket_white", S("White Picket Fence Gate") },
+ { "barbed_wire", S("Barbed Wire Fence Gate") },
+ { "chainlink", S("Chainlink Fence Gate") },
+ { "half_door", S("\"Half\" Door") },
+ { "half_door_white", S("\"Half\" Door (white)") }
}
local gate_models_closed = {
@@ -315,7 +317,12 @@ local gate_models_closed = {
{ -8/16, 7/16, 13/32, 8/16, 8/16, 15/32 }, -- top piece
{ -8/16, -8/16, 13/32, 8/16, -7/16, 15/32 }, -- bottom piece
{ -8/16, -8/16, 7/16, 8/16, 8/16, 7/16 }, -- the chainlink itself
- { -8/16, -3/16, 6/16, -6/16, 3/16, 8/16 }} -- the lump representing the lock
+ { -8/16, -3/16, 6/16, -6/16, 3/16, 8/16 }}, -- the lump representing the lock
+
+ {{ -8/16, -8/16, 6/16, 8/16, 8/16, 8/16 }}, -- the whole door :P
+
+ {{ -8/16, -8/16, 6/16, 8/16, 8/16, 8/16 }}, -- the whole door :P
+
}
local gate_models_open = {
@@ -334,7 +341,11 @@ local gate_models_open = {
{ 13/32, 7/16, -8/16, 15/32, 8/16, 8/16 }, -- top piece
{ 13/32, -8/16, -8/16, 15/32, -7/16, 8/16 }, -- bottom piece
{ 7/16, -8/16, -8/16, 7/16, 8/16, 8/16 }, -- the chainlink itself
- { 6/16, -3/16, -8/16, 8/16, 3/16, -6/16 }} -- the lump representing the lock
+ { 6/16, -3/16, -8/16, 8/16, 3/16, -6/16 }}, -- the lump representing the lock
+
+ {{ 6/16, -8/16, -8/16, 8/16, 8/16, 8/16 }}, -- the whole door :P
+
+ {{ 6/16, -8/16, -8/16, 8/16, 8/16, 8/16 }}, -- the whole door :P
}
for i, g in ipairs(gate_list) do
@@ -409,8 +420,8 @@ for i, g in ipairs(gate_list) do
def.selection_box.fixed = { 0.4, -0.5, -0.5, 0.5, 0.5, 0.5 }
def.node_box.fixed = gate_models_open[i]
def.tiles = {
- tiles[1],
- tiles[2],
+ tiles[1].."^[transformR90",
+ tiles[2].."^[transformR270",
tiles[6],
tiles[5],
tiles[4],